// 加载功能页面到功能区
function loadPage(url) {
    // 显示加载指示器
    document.getElementById('module-content').innerHTML = '<div class="loading">加载中...</div>';

    // 使用AJAX加载页面内容
    fetch(url)
        .then(response => response.text())
        .then(data => {
            document.getElementById('module-content').innerHTML = data;
            // 更新URL但不刷新页面
            history.pushState(null, null, '?page=' + url);
            // 更新左侧导航菜单高亮
            updateActiveNav(url);
        })
        .catch(error => {
            document.getElementById('module-content').innerHTML = '<div class="alert alert-error">加载失败：' + error.message + '</div>';
        });
}

// 更新左侧导航菜单高亮
function updateActiveNav(url) {
    // 移除所有导航项的active类
    document.querySelectorAll('.module-nav-item').forEach(item => {
        item.classList.remove('active');
    });

    // 为当前导航项添加active类
    document.querySelectorAll('.module-nav-item').forEach(item => {
        if (item.getAttribute('data-url') === url) {
            item.classList.add('active');
        }
    });
}

// 页面加载完成后执行
document.addEventListener('DOMContentLoaded', function () {
    // 设置导航项点击事件
    document.querySelectorAll('.module-nav-item').forEach(item => {
        item.addEventListener('click', function (e) {
            e.preventDefault();
            const url = this.getAttribute('data-url');
            loadPage(url);
        });
    });

    // 加载默认页面或URL参数指定的页面
    const urlParams = new URLSearchParams(window.location.search);
    const page = urlParams.get('page');

    if (page) {
        loadPage(page);
    } else {
        // 加载默认页面
        const defaultNavItem = document.querySelector('.module-nav-item:nth-child(2)');
        if (defaultNavItem) {
            const defaultUrl = defaultNavItem.getAttribute('data-url');
            loadPage(defaultUrl);
        }
    }
});

/**
 * 初始化全选/取消全选功能
 * @param {string} selectAllId - 全选复选框的ID
 * @param {string} itemClass - 项目复选框的类名
 */
function initCheckboxToggle(selectAllId, itemClass) {
    // 全选/取消全选
    const selectAll = document.getElementById(selectAllId);
    if (!selectAll) return;

    selectAll.addEventListener('change', function () {
        const checkboxes = document.getElementsByClassName(itemClass);
        for (let i = 0; i < checkboxes.length; i++) {
            checkboxes[i].checked = this.checked;
        }
    });

    // 如果所有复选框都被勾选，则"全选"复选框也应该被勾选
    const itemCheckboxes = document.getElementsByClassName(itemClass);
    for (let i = 0; i < itemCheckboxes.length; i++) {
        itemCheckboxes[i].addEventListener('change', function () {
            let allChecked = true;
            for (let j = 0; j < itemCheckboxes.length; j++) {
                if (!itemCheckboxes[j].checked) {
                    allChecked = false;
                    break;
                }
            }
            selectAll.checked = allChecked;
        });
    }
}

/**
 * 确认操作对话框
 * @param {string} message - 确认消息
 * @param {function} callback - 确认后的回调函数
 */
function confirmAction(message, callback) {
    if (confirm(message)) {
        callback();
    }
}

/**
 * 动态加载下拉框选项
 * @param {string} url - 要请求的URL
 * @param {string} targetSelectId - 目标下拉框ID
 * @param {string} valueField - 值字段名
 * @param {string} textField - 文本字段名
 * @param {string} defaultOption - 默认选项文本
 */
function loadSelectOptions(url, targetSelectId, valueField, textField, defaultOption = '请选择') {
    const select = document.getElementById(targetSelectId);
    if (!select) return;

    // 清空现有选项，保留默认选项
    select.innerHTML = `<option value="">${defaultOption}</option>`;

    // 获取数据
    fetch(url)
        .then(response => response.json())
        .then(data => {
            if (Array.isArray(data) && data.length > 0) {
                data.forEach(item => {
                    const option = document.createElement('option');
                    option.value = item[valueField];
                    option.textContent = item[textField];
                    select.appendChild(option);
                });
            }
        })
        .catch(error => console.error('加载选项失败:', error));
}

/**
 * 为表单字段添加验证
 * @param {string} formId - 表单ID
 * @param {Object} validations - 验证规则对象
 */
function setupFormValidation(formId, validations) {
    const form = document.getElementById(formId);
    if (!form) return;

    form.addEventListener('submit', function (event) {
        let isValid = true;
        let firstInvalidField = null;

        // 清除所有错误消息
        const errorMessages = form.querySelectorAll('.field-error');
        errorMessages.forEach(el => el.remove());

        // 验证每个字段
        for (const fieldId in validations) {
            const field = document.getElementById(fieldId);
            if (!field) continue;

            const rules = validations[fieldId];
            let fieldValid = true;

            // 必填验证
            if (rules.required && field.value.trim() === '') {
                showFieldError(field, rules.required === true ? '此字段为必填项' : rules.required);
                fieldValid = false;
            }

            // 最小值验证
            if (fieldValid && rules.min !== undefined && Number(field.value) < rules.min) {
                showFieldError(field, `最小值为 ${rules.min}`);
                fieldValid = false;
            }

            // 最大值验证
            if (fieldValid && rules.max !== undefined && Number(field.value) > rules.max) {
                showFieldError(field, `最大值为 ${rules.max}`);
                fieldValid = false;
            }

            // 正则表达式验证
            if (fieldValid && rules.pattern && !new RegExp(rules.pattern).test(field.value)) {
                showFieldError(field, rules.patternMessage || '格式不正确');
                fieldValid = false;
            }

            if (!fieldValid) {
                isValid = false;
                if (firstInvalidField === null) {
                    firstInvalidField = field;
                }
            }
        }

        if (!isValid) {
            event.preventDefault();
            if (firstInvalidField) {
                firstInvalidField.focus();
            }
        }
    });

    function showFieldError(field, message) {
        const errorDiv = document.createElement('div');
        errorDiv.className = 'field-error';
        errorDiv.style.color = 'red';
        errorDiv.style.fontSize = '12px';
        errorDiv.style.marginTop = '5px';
        errorDiv.textContent = message;

        field.parentNode.appendChild(errorDiv);
    }
} 