<?php

/**
 * 数据统计脚本
 * 用于生成报表数据，由系统定时任务调用
 */

// 获取正确的路径
$basePath = realpath(dirname(__FILE__) . '/../../');

// 加载配置文件
require_once $basePath . '/config/config.php';
require_once $basePath . '/includes/functions.php';

// 初始化消息变量
$messages = [];

// 确保脚本只能通过命令行或内部调用执行
$isCommandLine = (php_sapi_name() === 'cli');
$isInternalCall = defined('IN_SYSTEM') && IN_SYSTEM === true;

if (!$isCommandLine && !$isInternalCall) {
    die('此脚本只能通过命令行或系统内部调用执行');
}

/**
 * 生成热门商品统计数据 - 使用真实销售数据
 */
function generatePopularProductStats()
{
    global $conn, $messages;
    $localMessages = [];

    $localMessages[] = '开始生成热门商品统计数据...';

    // 当前日期
    $today = date('Y-m-d');
    $thisMonth = date('Y-m-01');
    $thisYear = date('Y-01-01');
    $periodType = 'month';

    // 清空当前统计周期的数据
    $clearSql = "DELETE FROM product_popularity WHERE period_type = ? AND stat_date = ?";
    $clearStmt = $conn->prepare($clearSql);
    $clearStmt->bind_param('ss', $periodType, $thisMonth);
    $clearStmt->execute();
    $localMessages[] = '已清除当前月度统计数据';

    // 使用真实销售数据的SQL - 按销量计算热门商品
    $statSql = "INSERT INTO product_popularity 
                (product_id, stat_date, period_type, sales_count, sales_amount, profit, profit_rate, 
                 rank_by_count, rank_by_amount, rank_by_profit)
                
                WITH sales_data AS (
                    SELECT 
                        soi.product_id,
                        p.product_name,
                        SUM(soi.quantity) AS total_quantity,
                        SUM(soi.quantity * soi.unit_price) AS total_amount,
                        -- 使用70%的销售额估算利润（因为没有purchase_price字段）
                        SUM(soi.quantity * soi.unit_price * 0.3) AS total_profit,
                        30 AS profit_rate -- 固定30%的利润率
                    FROM sales_order_items soi
                    JOIN sales_orders so ON soi.order_id = so.order_id
                    JOIN products p ON soi.product_id = p.product_id
                    WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
                    AND so.order_status IN ('completed', 'shipping')
                    GROUP BY soi.product_id, p.product_name
                ),
                
                ranked_sales AS (
                    SELECT 
                        product_id,
                        total_quantity,
                        total_amount,
                        total_profit,
                        profit_rate,
                        RANK() OVER (ORDER BY total_quantity DESC) as rank_count,
                        RANK() OVER (ORDER BY total_amount DESC) as rank_amount,
                        RANK() OVER (ORDER BY total_profit DESC) as rank_profit
                    FROM sales_data
                )
                
                SELECT 
                    product_id,
                    ? AS stat_date,
                    ? AS period_type,
                    total_quantity,
                    total_amount,
                    total_profit,
                    profit_rate,
                    rank_count,
                    rank_amount,
                    rank_profit
                FROM ranked_sales";

    // 如果数据库不支持WITH语法或RANK()函数，则使用替代方案
    if (!$conn->query("SELECT 1")) { // 简单测试SQL特性支持
        $localMessages[] = '数据库不支持高级SQL特性，使用替代方案...';

        // 第一步：获取销售数据
        $salesDataSql = "SELECT 
                            soi.product_id,
                            SUM(soi.quantity) AS total_quantity,
                            SUM(soi.quantity * soi.unit_price) AS total_amount,
                            SUM(soi.quantity * (soi.unit_price - p.unit_price * 0.7)) AS total_profit
                        FROM sales_order_items soi
                        JOIN sales_orders so ON soi.order_id = so.order_id
                        JOIN products p ON soi.product_id = p.product_id
                        WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
                        AND so.order_status IN ('completed', 'shipping')
                        GROUP BY soi.product_id";

        $salesDataStmt = $conn->prepare($salesDataSql);
        $salesDataStmt->bind_param('ss', $thisMonth, $thisMonth);
        $salesDataStmt->execute();
        $salesResult = $salesDataStmt->get_result();

        // 创建销售数据数组
        $salesData = [];
        while ($row = $salesResult->fetch_assoc()) {
            $profitRate = ($row['total_amount'] > 0)
                ? ($row['total_profit'] / $row['total_amount']) * 100
                : 0;

            $salesData[] = [
                'product_id' => $row['product_id'],
                'total_quantity' => $row['total_quantity'],
                'total_amount' => $row['total_amount'],
                'total_profit' => $row['total_profit'],
                'profit_rate' => $profitRate
            ];
        }

        // 对销售数据进行排序
        $quantityRank = $amountRank = $profitRank = [];
        foreach ($salesData as $key => $row) {
            $quantityRank[$key] = $row['total_quantity'];
            $amountRank[$key] = $row['total_amount'];
            $profitRank[$key] = $row['total_profit'];
        }
        array_multisort($quantityRank, SORT_DESC, $salesData);

        // 分配排名
        $rankByCount = $rankByAmount = $rankByProfit = [];
        foreach ($salesData as $i => $data) {
            $rankByCount[$data['product_id']] = $i + 1;
        }

        array_multisort($amountRank, SORT_DESC, $salesData);
        foreach ($salesData as $i => $data) {
            $rankByAmount[$data['product_id']] = $i + 1;
        }

        array_multisort($profitRank, SORT_DESC, $salesData);
        foreach ($salesData as $i => $data) {
            $rankByProfit[$data['product_id']] = $i + 1;
        }

        // 恢复原始排序
        array_multisort($quantityRank, SORT_DESC, $salesData);

        // 插入数据
        $insertSql = "INSERT INTO product_popularity 
                     (product_id, stat_date, period_type, sales_count, sales_amount, profit, profit_rate, 
                      rank_by_count, rank_by_amount, rank_by_profit) 
                     VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                     ON DUPLICATE KEY UPDATE
                      sales_count = VALUES(sales_count),
                      sales_amount = VALUES(sales_amount),
                      profit = VALUES(profit),
                      profit_rate = VALUES(profit_rate),
                      rank_by_count = VALUES(rank_by_count),
                      rank_by_amount = VALUES(rank_by_amount),
                      rank_by_profit = VALUES(rank_by_profit),
                      updated_at = NOW()";
        $insertStmt = $conn->prepare($insertSql);

        if (!$insertStmt) {
            $localMessages[] = '准备插入语句失败: ' . $conn->error;
            return [false, $localMessages];
        }

        foreach ($salesData as $data) {
            $productId = $data['product_id'];
            $insertStmt->bind_param(
                'issiiddiii',
                $productId,
                $thisMonth,
                $periodType,
                $data['total_quantity'],
                $data['total_amount'],
                $data['total_profit'],
                $data['profit_rate'],
                $rankByCount[$productId],
                $rankByAmount[$productId],
                $rankByProfit[$productId]
            );

            if ($insertStmt->execute()) {
                $localMessages[] = "生成商品[{$productId}]的热门统计数据成功";
            } else {
                $localMessages[] = "生成商品[{$productId}]的热门统计数据失败: " . $insertStmt->error;
            }
        }
    } else {
        // 使用WITH和RANK()的原始SQL
        $statStmt = $conn->prepare($statSql);
        if (!$statStmt) {
            $localMessages[] = '准备热门商品统计SQL失败: ' . $conn->error;
            return [false, $localMessages];
        }

        $statStmt->bind_param('ssss', $thisMonth, $thisMonth, $thisMonth, $periodType);

        if ($statStmt->execute()) {
            $affectedRows = $statStmt->affected_rows;
            $localMessages[] = "成功生成{$affectedRows}条热门商品统计数据";
        } else {
            $localMessages[] = "生成热门商品统计数据失败: " . $statStmt->error;
            return [false, $localMessages];
        }
    }

    $localMessages[] = '热门商品统计数据生成完成';
    return [true, $localMessages];
}

/**
 * 生成库存分析统计数据 - 使用真实库存和销售数据
 */
function generateInventoryAnalysisStats()
{
    global $conn, $messages;
    $localMessages = [];

    $localMessages[] = '开始生成库存分析统计数据...';

    // 当前日期
    $today = date('Y-m-d');
    $thisMonth = date('Y-m-01');
    $periodType = 'month';

    // 清空当前统计周期的数据
    $clearSql = "DELETE FROM inventory_analysis WHERE period_type = ? AND stat_date = ?";
    $clearStmt = $conn->prepare($clearSql);
    $clearStmt->bind_param('ss', $periodType, $thisMonth);
    $clearStmt->execute();
    $localMessages[] = '已清除当前月度库存分析数据';

    // 1. 首先获取当前库存数据
    $inventoryQuery = "
        SELECT i.*, p.product_name, p.unit_price
        FROM inventory i
        JOIN products p ON i.product_id = p.product_id
    ";
    $inventoryResult = $conn->query($inventoryQuery);

    if (!$inventoryResult) {
        $localMessages[] = '获取库存数据失败: ' . $conn->error;
        return [false, $localMessages];
    }

    // 2. 获取过去30天销售数据
    $salesQuery = "
        SELECT soi.product_id, 
               SUM(soi.quantity) AS total_sales,
               MAX(so.order_date) AS last_sale_date
        FROM sales_order_items soi
        JOIN sales_orders so ON soi.order_id = so.order_id
        WHERE so.order_date BETWEEN DATE_SUB(?, INTERVAL 30 DAY) AND ?
        AND so.order_status IN ('completed', 'shipping')
        GROUP BY soi.product_id
    ";
    $salesStmt = $conn->prepare($salesQuery);
    $salesStmt->bind_param('ss', $today, $today);
    $salesStmt->execute();
    $salesResult = $salesStmt->get_result();

    $salesData = [];
    while ($row = $salesResult->fetch_assoc()) {
        $salesData[$row['product_id']] = [
            'total_sales' => $row['total_sales'],
            'last_sale_date' => $row['last_sale_date']
        ];
    }

    // 3. 获取缺货记录
    $stockoutQuery = "
        SELECT soi.product_id, COUNT(*) AS stockout_count
        FROM sales_orders so
        JOIN sales_order_items soi ON so.order_id = soi.order_id
        JOIN inventory i ON soi.product_id = i.product_id
        WHERE so.order_date BETWEEN DATE_SUB(?, INTERVAL 30 DAY) AND ?
        AND soi.quantity > i.quantity
        GROUP BY soi.product_id
    ";
    $stockoutStmt = $conn->prepare($stockoutQuery);
    $stockoutStmt->bind_param('ss', $today, $today);
    $stockoutStmt->execute();
    $stockoutResult = $stockoutStmt->get_result();

    $stockoutData = [];
    while ($row = $stockoutResult->fetch_assoc()) {
        $stockoutData[$row['product_id']] = $row['stockout_count'];
    }

    // 4. 准备插入数据的SQL，使用ON DUPLICATE KEY UPDATE处理重复记录
    $insertSql = "INSERT INTO inventory_analysis
                 (product_id, warehouse_id, stat_date, period_type,
                  beginning_inventory, ending_inventory, sales_quantity,
                  turnover_rate, days_of_inventory, slow_moving_days, stockout_times, is_alert, alert_type)
                 VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                 ON DUPLICATE KEY UPDATE
                  beginning_inventory = VALUES(beginning_inventory),
                  ending_inventory = VALUES(ending_inventory),
                  sales_quantity = VALUES(sales_quantity),
                  turnover_rate = VALUES(turnover_rate),
                  days_of_inventory = VALUES(days_of_inventory),
                  slow_moving_days = VALUES(slow_moving_days),
                  stockout_times = VALUES(stockout_times),
                  is_alert = VALUES(is_alert),
                  alert_type = VALUES(alert_type),
                  updated_at = NOW()";
    $insertStmt = $conn->prepare($insertSql);

    if (!$insertStmt) {
        $localMessages[] = '准备插入SQL失败: ' . $conn->error;
        return [false, $localMessages];
    }

    // 5. 处理每一条库存记录
    $successCount = 0;
    while ($inventory = $inventoryResult->fetch_assoc()) {
        $productId = $inventory['product_id'];
        $warehouseId = $inventory['warehouse_id'];
        $currentQty = $inventory['quantity'];

        // 获取销售数据
        $salesQty = isset($salesData[$productId]) ? $salesData[$productId]['total_sales'] : 0;
        $lastSaleDate = isset($salesData[$productId]) ? $salesData[$productId]['last_sale_date'] : null;

        // 计算周转率 = 月销售量 / 平均库存量
        $turnoverRate = ($currentQty > 0) ? ($salesQty / $currentQty) : 0;

        // 计算库存天数 = 30 / 周转率
        $daysOfInventory = ($turnoverRate > 0) ? (30 / $turnoverRate) : 999;

        // 计算最后一次销售距今天数
        $slowMovingDays = ($lastSaleDate) ?
            (int)((strtotime($today) - strtotime($lastSaleDate)) / 86400) :
            999;

        // 获取缺货次数
        $stockoutTimes = isset($stockoutData[$productId]) ? $stockoutData[$productId] : 0;

        // 判断是否需要预警
        $isAlert = 0;
        $alertType = null;

        // 库存低于最低库存预警
        if ($currentQty <= $inventory['min_stock_level']) {
            $isAlert = 1;
            $alertType = '缺货';
        }
        // 60天未销售预警
        else if ($slowMovingDays > 60) {
            $isAlert = 1;
            $alertType = '呆滞';
        }
        // 过高库存周转天数预警
        else if ($daysOfInventory > 90) {
            $isAlert = 1;
            $alertType = '积压';
        }

        // 插入数据
        $insertStmt->bind_param(
            'iissiiiddiiis',
            $productId,
            $warehouseId,
            $thisMonth,
            $periodType,
            $currentQty,
            $currentQty,
            $salesQty,
            $turnoverRate,
            $daysOfInventory,
            $slowMovingDays,
            $stockoutTimes,
            $isAlert,
            $alertType
        );

        if ($insertStmt->execute()) {
            $successCount++;
        } else {
            $localMessages[] = "生成商品[{$productId}]的库存分析数据失败: " . $insertStmt->error;
        }
    }

    $localMessages[] = "成功生成{$successCount}条库存分析数据";
    $localMessages[] = '库存分析统计数据生成完成';
    return [true, $localMessages];
}

/**
 * 生成销售分析统计数据
 */
function generateSalesAnalysisStats()
{
    global $conn, $messages;
    $localMessages = [];

    $localMessages[] = '开始生成销售分析统计数据...';

    // 当前日期
    $today = date('Y-m-d');
    $thisMonth = date('Y-m-01');
    $periodType = 'month';

    // 清空当前统计周期的数据
    $clearSql = "DELETE FROM custom_sales_analysis WHERE period_type = ? AND stat_date = ?";
    $clearStmt = $conn->prepare($clearSql);
    if (!$clearStmt) {
        $localMessages[] = '准备清空销售分析SQL失败: ' . $conn->error;
        return [false, $localMessages];
    }
    $clearStmt->bind_param('ss', $periodType, $thisMonth);
    $clearStmt->execute();
    $localMessages[] = '已清除当前月度销售分析数据';

    // 按客户维度统计销售数据
    $customerStatSql = "INSERT INTO custom_sales_analysis 
               (stat_date, period_type, dimension_type, dimension_id, dimension_name,
                order_count, customer_count, sales_quantity, sales_amount, 
                avg_order_value, rank_by_amount)
               
               SELECT 
                   ? AS stat_date,
                   ? AS period_type,
                   'customer' AS dimension_type,
                   c.customer_id AS dimension_id,
                   c.customer_name AS dimension_name,
                   COUNT(DISTINCT so.order_id) AS order_count,
                   1 AS customer_count,
                   SUM(soi.quantity) AS sales_quantity,
                   SUM(soi.quantity * soi.unit_price) AS sales_amount,
                   SUM(soi.quantity * soi.unit_price) / NULLIF(COUNT(DISTINCT so.order_id), 0) AS avg_order_value,
                   0 AS rank_by_amount -- 将在后续更新
               FROM sales_orders so
               JOIN sales_order_items soi ON so.order_id = soi.order_id
               JOIN customers c ON so.customer_id = c.customer_id
               WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
               AND so.order_status IN ('completed', 'shipping')
               GROUP BY c.customer_id, c.customer_name
               ON DUPLICATE KEY UPDATE
                order_count = VALUES(order_count),
                customer_count = VALUES(customer_count),
                sales_quantity = VALUES(sales_quantity),
                sales_amount = VALUES(sales_amount),
                avg_order_value = VALUES(avg_order_value)";

    $customerStatStmt = $conn->prepare($customerStatSql);
    if (!$customerStatStmt) {
        $localMessages[] = '准备客户维度销售分析SQL失败: ' . $conn->error;
        return [false, $localMessages];
    }

    $customerStatStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $thisMonth);

    if ($customerStatStmt->execute()) {
        $affectedRows = $customerStatStmt->affected_rows;
        $localMessages[] = "成功生成{$affectedRows}条客户维度销售分析数据";
    } else {
        $localMessages[] = "生成客户维度销售分析数据失败: " . $customerStatStmt->error;
        return [false, $localMessages];
    }

    // 按商品维度统计销售数据
    $productStatSql = "INSERT INTO custom_sales_analysis 
               (stat_date, period_type, dimension_type, dimension_id, dimension_name,
                order_count, customer_count, sales_quantity, sales_amount, 
                avg_order_value, rank_by_amount)
               
               SELECT 
                   ? AS stat_date,
                   ? AS period_type,
                   'product' AS dimension_type,
                   p.product_id AS dimension_id,
                   p.product_name AS dimension_name,
                   COUNT(DISTINCT so.order_id) AS order_count,
                   COUNT(DISTINCT so.customer_id) AS customer_count,
                   SUM(soi.quantity) AS sales_quantity,
                   SUM(soi.quantity * soi.unit_price) AS sales_amount,
                   SUM(soi.quantity * soi.unit_price) / NULLIF(COUNT(DISTINCT so.order_id), 0) AS avg_order_value,
                   0 AS rank_by_amount
               FROM sales_orders so
               JOIN sales_order_items soi ON so.order_id = soi.order_id
               JOIN products p ON soi.product_id = p.product_id
               WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
               AND so.order_status IN ('completed', 'shipping')
               GROUP BY p.product_id, p.product_name
               ON DUPLICATE KEY UPDATE
                order_count = VALUES(order_count),
                customer_count = VALUES(customer_count),
                sales_quantity = VALUES(sales_quantity),
                sales_amount = VALUES(sales_amount),
                avg_order_value = VALUES(avg_order_value)";

    $productStatStmt = $conn->prepare($productStatSql);
    if (!$productStatStmt) {
        $localMessages[] = '准备商品维度销售分析SQL失败: ' . $conn->error;
        return [false, $localMessages];
    }

    $productStatStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $thisMonth);

    if ($productStatStmt->execute()) {
        $affectedRows = $productStatStmt->affected_rows;
        $localMessages[] = "成功生成{$affectedRows}条商品维度销售分析数据";
    } else {
        $localMessages[] = "生成商品维度销售分析数据失败: " . $productStatStmt->error;
        return [false, $localMessages];
    }

    // 更新客户维度排名
    $customerRankSql = "UPDATE custom_sales_analysis 
                     SET rank_by_amount = (
                         SELECT r.`rank` 
                         FROM (
                             SELECT 
                                 dimension_id,
                                 @rank := @rank + 1 as `rank`
                             FROM custom_sales_analysis, (SELECT @rank := 0) r
                             WHERE stat_date = ? AND period_type = ? AND dimension_type = 'customer'
                             ORDER BY sales_amount DESC
                         ) r
                         WHERE r.dimension_id = custom_sales_analysis.dimension_id
                     )
                     WHERE stat_date = ? AND period_type = ? AND dimension_type = 'customer'";

    $customerRankStmt = $conn->prepare($customerRankSql);
    if (!$customerRankStmt) {
        $localMessages[] = '准备客户排名SQL失败: ' . $conn->error;
    } else {
        $customerRankStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $periodType);
        $customerRankStmt->execute();
        $localMessages[] = "更新客户销售排名完成";
    }

    // 更新商品维度排名
    $productRankSql = "UPDATE custom_sales_analysis 
                    SET rank_by_amount = (
                        SELECT r.`rank` 
                        FROM (
                            SELECT 
                                dimension_id,
                                @prank := @prank + 1 as `rank`
                            FROM custom_sales_analysis, (SELECT @prank := 0) r
                            WHERE stat_date = ? AND period_type = ? AND dimension_type = 'product'
                            ORDER BY sales_amount DESC
                        ) r
                        WHERE r.dimension_id = custom_sales_analysis.dimension_id
                    )
                    WHERE stat_date = ? AND period_type = ? AND dimension_type = 'product'";

    $productRankStmt = $conn->prepare($productRankSql);
    if (!$productRankStmt) {
        $localMessages[] = '准备商品排名SQL失败: ' . $conn->error;
    } else {
        $productRankStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $periodType);
        $productRankStmt->execute();
        $localMessages[] = "更新商品销售排名完成";
    }

    $localMessages[] = '销售分析统计数据生成完成';
    return [true, $localMessages];
}

/**
 * 生成利润分析统计数据
 */
function generateProfitAnalysisStats()
{
    global $conn, $messages;
    $localMessages = [];

    $localMessages[] = '开始生成利润分析统计数据...';

    // 当前日期
    $today = date('Y-m-d');
    $thisMonth = date('Y-m-01');
    $periodType = 'month';

    // 清空当前统计周期的数据
    $clearSql = "DELETE FROM profit_analysis WHERE period_type = ? AND stat_date = ?";
    $clearStmt = $conn->prepare($clearSql);
    $clearStmt->bind_param('ss', $periodType, $thisMonth);
    $clearStmt->execute();
    $localMessages[] = '已清除当前月度利润分析数据';

    // 尝试从purchase_stock_items获取采购价格信息
    $hasPurchaseData = false;
    $purchaseDataSql = "SHOW TABLES LIKE 'purchase_stock_items'";
    $result = $conn->query($purchaseDataSql);
    if ($result && $result->num_rows > 0) {
        $hasPurchaseData = true;
        $localMessages[] = '检测到采购数据表，将使用实际采购价格计算利润';
    } else {
        $localMessages[] = '未检测到采购数据表，将使用估算成本计算利润(销售价的70%)';
    }

    // 按品牌维度统计利润数据（替代类别）
    $brandProfitSql = "";

    if ($hasPurchaseData) {
        // 使用采购价格计算利润
        $brandProfitSql = "INSERT INTO profit_analysis 
                (stat_date, period_type, dimension_type, dimension_id, dimension_name,
                 sales_amount, cost_amount, gross_profit, profit_rate, rank_by_profit)
                
                SELECT 
                    ? AS stat_date,
                    ? AS period_type,
                    'brand' AS dimension_type,
                    (@brand_id:=@brand_id+1) AS dimension_id,
                    IFNULL(p.brand, '未分类') AS dimension_name,
                    SUM(soi.quantity * soi.unit_price) AS sales_amount,
                    SUM(soi.quantity * COALESCE(psi.unit_price, soi.unit_price * 0.7)) AS cost_amount,
                    SUM(soi.quantity * soi.unit_price) - SUM(soi.quantity * COALESCE(psi.unit_price, soi.unit_price * 0.7)) AS gross_profit,
                    (SUM(soi.quantity * soi.unit_price) - SUM(soi.quantity * COALESCE(psi.unit_price, soi.unit_price * 0.7))) / NULLIF(SUM(soi.quantity * soi.unit_price), 0) * 100 AS profit_rate,
                    0 AS rank_by_profit
                FROM sales_orders so
                JOIN sales_order_items soi ON so.order_id = soi.order_id
                JOIN products p ON soi.product_id = p.product_id
                CROSS JOIN (SELECT @brand_id:=0) AS b
                LEFT JOIN (
                    SELECT 
                        product_name,
                        AVG(unit_price) AS unit_price
                    FROM purchase_stock_items
                    GROUP BY product_name
                ) psi ON p.product_name = psi.product_name
                WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
                AND so.order_status IN ('completed', 'shipping')
                GROUP BY IFNULL(p.brand, '未分类')
                ON DUPLICATE KEY UPDATE
                 sales_amount = VALUES(sales_amount),
                 cost_amount = VALUES(cost_amount),
                 gross_profit = VALUES(gross_profit),
                 profit_rate = VALUES(profit_rate)";
    } else {
        // 使用估算成本（销售价的70%）
        $brandProfitSql = "INSERT INTO profit_analysis 
                (stat_date, period_type, dimension_type, dimension_id, dimension_name,
                 sales_amount, cost_amount, gross_profit, profit_rate, rank_by_profit)
                
                SELECT 
                    ? AS stat_date,
                    ? AS period_type,
                    'brand' AS dimension_type,
                    (@brand_id:=@brand_id+1) AS dimension_id,
                    IFNULL(p.brand, '未分类') AS dimension_name,
                    SUM(soi.quantity * soi.unit_price) AS sales_amount,
                    SUM(soi.quantity * soi.unit_price * 0.7) AS cost_amount,
                    SUM(soi.quantity * soi.unit_price * 0.3) AS gross_profit,
                    30 AS profit_rate,
                    0 AS rank_by_profit
                FROM sales_orders so
                JOIN sales_order_items soi ON so.order_id = soi.order_id
                JOIN products p ON soi.product_id = p.product_id
                CROSS JOIN (SELECT @brand_id:=0) AS b
                WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
                AND so.order_status IN ('completed', 'shipping')
                GROUP BY IFNULL(p.brand, '未分类')
                ON DUPLICATE KEY UPDATE
                 sales_amount = VALUES(sales_amount),
                 cost_amount = VALUES(cost_amount),
                 gross_profit = VALUES(gross_profit),
                 profit_rate = VALUES(profit_rate)";
    }

    $brandProfitStmt = $conn->prepare($brandProfitSql);
    if (!$brandProfitStmt) {
        $localMessages[] = '准备品牌维度利润分析SQL失败: ' . $conn->error;
        return [false, $localMessages];
    }

    $brandProfitStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $thisMonth);

    if ($brandProfitStmt->execute()) {
        $affectedRows = $brandProfitStmt->affected_rows;
        $localMessages[] = "成功生成{$affectedRows}条品牌维度利润分析数据";
    } else {
        $localMessages[] = "生成品牌维度利润分析数据失败: " . $brandProfitStmt->error;
        return [false, $localMessages];
    }

    // 按商品维度统计利润数据
    $productProfitSql = "";

    if ($hasPurchaseData) {
        $productProfitSql = "INSERT INTO profit_analysis 
                (stat_date, period_type, dimension_type, dimension_id, dimension_name,
                 sales_amount, cost_amount, gross_profit, profit_rate, rank_by_profit)
                
                SELECT 
                    ? AS stat_date,
                    ? AS period_type,
                    'product' AS dimension_type,
                    p.product_id AS dimension_id,
                    p.product_name AS dimension_name,
                    SUM(soi.quantity * soi.unit_price) AS sales_amount,
                    SUM(soi.quantity * COALESCE(psi.unit_price, soi.unit_price * 0.7)) AS cost_amount,
                    SUM(soi.quantity * soi.unit_price) - SUM(soi.quantity * COALESCE(psi.unit_price, soi.unit_price * 0.7)) AS gross_profit,
                    (SUM(soi.quantity * soi.unit_price) - SUM(soi.quantity * COALESCE(psi.unit_price, soi.unit_price * 0.7))) / NULLIF(SUM(soi.quantity * soi.unit_price), 0) * 100 AS profit_rate,
                    0 AS rank_by_profit
                FROM sales_orders so
                JOIN sales_order_items soi ON so.order_id = soi.order_id
                JOIN products p ON soi.product_id = p.product_id
                LEFT JOIN (
                    SELECT 
                        product_name,
                        AVG(unit_price) AS unit_price
                    FROM purchase_stock_items
                    GROUP BY product_name
                ) psi ON p.product_name = psi.product_name
                WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
                AND so.order_status IN ('completed', 'shipping')
                GROUP BY p.product_id, p.product_name
                ON DUPLICATE KEY UPDATE
                 sales_amount = VALUES(sales_amount),
                 cost_amount = VALUES(cost_amount),
                 gross_profit = VALUES(gross_profit),
                 profit_rate = VALUES(profit_rate)";
    } else {
        $productProfitSql = "INSERT INTO profit_analysis 
                (stat_date, period_type, dimension_type, dimension_id, dimension_name,
                 sales_amount, cost_amount, gross_profit, profit_rate, rank_by_profit)
                
                SELECT 
                    ? AS stat_date,
                    ? AS period_type,
                    'product' AS dimension_type,
                    p.product_id AS dimension_id,
                    p.product_name AS dimension_name,
                    SUM(soi.quantity * soi.unit_price) AS sales_amount,
                    SUM(soi.quantity * soi.unit_price * 0.7) AS cost_amount,
                    SUM(soi.quantity * soi.unit_price * 0.3) AS gross_profit,
                    30 AS profit_rate,
                    0 AS rank_by_profit
                FROM sales_orders so
                JOIN sales_order_items soi ON so.order_id = soi.order_id
                JOIN products p ON soi.product_id = p.product_id
                WHERE so.order_date BETWEEN ? AND LAST_DAY(?)
                AND so.order_status IN ('completed', 'shipping')
                GROUP BY p.product_id, p.product_name
                ON DUPLICATE KEY UPDATE
                 sales_amount = VALUES(sales_amount),
                 cost_amount = VALUES(cost_amount),
                 gross_profit = VALUES(gross_profit),
                 profit_rate = VALUES(profit_rate)";
    }

    $productProfitStmt = $conn->prepare($productProfitSql);
    if (!$productProfitStmt) {
        $localMessages[] = '准备商品维度利润分析SQL失败: ' . $conn->error;
        return [false, $localMessages];
    }

    $productProfitStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $thisMonth);

    if ($productProfitStmt->execute()) {
        $affectedRows = $productProfitStmt->affected_rows;
        $localMessages[] = "成功生成{$affectedRows}条商品维度利润分析数据";
    } else {
        $localMessages[] = "生成商品维度利润分析数据失败: " . $productProfitStmt->error;
        return [false, $localMessages];
    }

    // 更新品牌维度排名
    $brandRankSql = "UPDATE profit_analysis 
                     SET rank_by_profit = (
                         SELECT r.`rank` 
                         FROM (
                             SELECT 
                                 dimension_id,
                                 @rank := @rank + 1 as `rank`
                             FROM profit_analysis, (SELECT @rank := 0) r
                             WHERE stat_date = ? AND period_type = ? AND dimension_type = 'brand'
                             ORDER BY gross_profit DESC
                         ) r
                         WHERE r.dimension_id = profit_analysis.dimension_id
                     )
                     WHERE stat_date = ? AND period_type = ? AND dimension_type = 'brand'";

    $brandRankStmt = $conn->prepare($brandRankSql);
    if (!$brandRankStmt) {
        $localMessages[] = '准备品牌排名SQL失败: ' . $conn->error;
    } else {
        $brandRankStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $periodType);
        $brandRankStmt->execute();
        $localMessages[] = "更新品牌利润排名完成";
    }

    // 更新商品维度排名
    $productRankSql = "UPDATE profit_analysis 
                    SET rank_by_profit = (
                        SELECT r.`rank` 
                        FROM (
                            SELECT 
                                dimension_id,
                                @prank := @prank + 1 as `rank`
                            FROM profit_analysis, (SELECT @prank := 0) r
                            WHERE stat_date = ? AND period_type = ? AND dimension_type = 'product'
                            ORDER BY gross_profit DESC
                        ) r
                        WHERE r.dimension_id = profit_analysis.dimension_id
                    )
                    WHERE stat_date = ? AND period_type = ? AND dimension_type = 'product'";

    $productRankStmt = $conn->prepare($productRankSql);
    if (!$productRankStmt) {
        $localMessages[] = '准备商品排名SQL失败: ' . $conn->error;
    } else {
        $productRankStmt->bind_param('ssss', $thisMonth, $periodType, $thisMonth, $periodType);
        $productRankStmt->execute();
        $localMessages[] = "更新商品利润排名完成";
    }

    $localMessages[] = '利润分析统计数据生成完成';
    return [true, $localMessages];
}

/**
 * 生成财务报表数据
 * 统计每日、每月、每年的财务数据，包括销售额、成本、毛利、净利润等
 */
function generateFinancialReportStats()
{
    global $conn;
    $messages = [];

    // 获取当前日期
    $today = date('Y-m-d');
    $thisMonth = date('Y-m-01');
    $thisYear = date('Y-01-01');

    try {
        // 清除当前的财务报表统计数据
        $clearSql = "DELETE FROM financial_reports WHERE 
                     (period_type = 'day' AND report_date = ?) OR 
                     (period_type = 'month' AND report_date = ?) OR 
                     (period_type = 'year' AND report_date = ?)";
        $clearStmt = $conn->prepare($clearSql);
        if (!$clearStmt) {
            throw new Exception("准备清除财务报表数据SQL语句失败: " . $conn->error);
        }

        $clearStmt->bind_param('sss', $today, $thisMonth, $thisYear);
        if (!$clearStmt->execute()) {
            throw new Exception("执行清除财务报表数据SQL语句失败: " . $clearStmt->error);
        }
        $clearStmt->close();
        $messages[] = "已清除当前财务报表统计数据";

        // 生成日报表数据
        $dayResult = generateFinancialReportForPeriod('day', $today);
        if (!$dayResult[0]) {
            throw new Exception("生成日报表数据失败: " . $dayResult[1][0]);
        }
        $messages[] = "已生成每日财务报表数据";

        // 生成月报表数据
        $monthResult = generateFinancialReportForPeriod('month', $thisMonth);
        if (!$monthResult[0]) {
            throw new Exception("生成月报表数据失败: " . $monthResult[1][0]);
        }
        $messages[] = "已生成每月财务报表数据";

        // 生成年报表数据
        $yearResult = generateFinancialReportForPeriod('year', $thisYear);
        if (!$yearResult[0]) {
            throw new Exception("生成年报表数据失败: " . $yearResult[1][0]);
        }
        $messages[] = "已生成每年财务报表数据";

        return [true, $messages];
    } catch (Exception $e) {
        return [false, ["生成财务报表数据时出错: " . $e->getMessage()]];
    }
}

/**
 * 根据指定的周期生成财务报表数据
 * 
 * @param string $periodType 周期类型: day, month, year
 * @param string $date 统计日期
 * @return array 包含成功状态和消息的数组 [bool, array]
 */
function generateFinancialReportForPeriod($periodType, $date)
{
    global $conn;
    $messages = [];

    try {
        // 根据周期类型确定日期范围
        $startDate = '';
        $endDate = '';

        switch ($periodType) {
            case 'day':
                $startDate = $date . ' 00:00:00';
                $endDate = $date . ' 23:59:59';
                break;
            case 'month':
                $startDate = $date . ' 00:00:00';
                $endDate = date('Y-m-t', strtotime($date)) . ' 23:59:59';
                break;
            case 'year':
                $startDate = $date . ' 00:00:00';
                $endDate = date('Y-12-31', strtotime($date)) . ' 23:59:59';
                break;
            default:
                return [false, ["无效的周期类型: " . $periodType]];
        }

        // 1. 获取销售总额和成本
        $salesSql = "SELECT 
                    SUM(soi.item_amount) AS total_sales,
                    SUM(IFNULL(p.unit_price * 0.7, soi.unit_price * 0.7) * soi.quantity) AS total_cost
                    FROM sales_order_items soi
                    JOIN sales_orders so ON soi.order_id = so.order_id
                    LEFT JOIN products p ON soi.product_id = p.product_id
                    WHERE so.order_date BETWEEN ? AND ?
                    AND so.order_status = 'completed'";

        $salesStmt = $conn->prepare($salesSql);
        if (!$salesStmt) {
            return [false, ["准备销售数据SQL语句失败: " . $conn->error]];
        }

        $salesStmt->bind_param('ss', $startDate, $endDate);
        if (!$salesStmt->execute()) {
            return [false, ["执行销售数据SQL语句失败: " . $salesStmt->error]];
        }

        $salesResult = $salesStmt->get_result();
        if (!$salesResult) {
            return [false, ["获取销售数据结果失败: " . $salesStmt->error]];
        }

        $salesData = $salesResult->fetch_assoc();
        $salesStmt->close();

        $totalSales = $salesData['total_sales'] ?? 0;
        $totalCost = $salesData['total_cost'] ?? 0;

        // 2. 计算毛利润和毛利率
        $grossProfit = $totalSales - $totalCost;
        $grossProfitRate = ($totalSales > 0) ? ($grossProfit / $totalSales * 100) : 0;

        // 3. 获取运营费用（检查expenses表是否存在）
        $operatingExpenses = 0;

        // 检查expenses表是否存在
        $tableCheckSql = "SHOW TABLES LIKE 'expenses'";
        $tableCheckResult = $conn->query($tableCheckSql);

        if ($tableCheckResult && $tableCheckResult->num_rows > 0) {
            $expensesSql = "SELECT SUM(amount) AS total_expenses
                        FROM expenses
                        WHERE expense_date BETWEEN ? AND ?";

            $expensesStmt = $conn->prepare($expensesSql);
            if (!$expensesStmt) {
                return [false, ["准备费用数据SQL语句失败: " . $conn->error]];
            }

            $expensesStmt->bind_param('ss', $startDate, $endDate);
            $expensesStmt->execute();
            $expensesResult = $expensesStmt->get_result();
            $expensesData = $expensesResult->fetch_assoc();
            $expensesStmt->close();

            $operatingExpenses = $expensesData['total_expenses'] ?? 0;
        } else {
            // 估算运营费用为毛利润的30%
            $operatingExpenses = $grossProfit * 0.3;
            $messages[] = "未找到expenses表，运营费用按毛利润的30%估算";
        }

        // 4. 计算净利润和净利率
        $netProfit = $grossProfit - $operatingExpenses;
        $netProfitRate = ($totalSales > 0) ? ($netProfit / $totalSales * 100) : 0;

        // 5. 获取应收账款总额（检查receivables表是否存在）
        $receivables = 0;

        // 检查receivables表是否存在
        $tableCheckSql = "SHOW TABLES LIKE 'receivables'";
        $tableCheckResult = $conn->query($tableCheckSql);

        if ($tableCheckResult && $tableCheckResult->num_rows > 0) {
            $receivablesSql = "SELECT SUM(remaining_amount) AS total_receivables
                           FROM receivables
                           WHERE due_date BETWEEN ? AND ?";

            $receivablesStmt = $conn->prepare($receivablesSql);
            if (!$receivablesStmt) {
                return [false, ["准备应收账款SQL语句失败: " . $conn->error]];
            }

            $receivablesStmt->bind_param('ss', $startDate, $endDate);
            $receivablesStmt->execute();
            $receivablesResult = $receivablesStmt->get_result();
            $receivablesData = $receivablesResult->fetch_assoc();
            $receivablesStmt->close();

            $receivables = $receivablesData['total_receivables'] ?? 0;
        } else {
            // 估算应收账款为销售额的20%
            $receivables = $totalSales * 0.2;
            $messages[] = "未找到receivables表，应收账款按销售额的20%估算";
        }

        // 6. 获取应付账款总额（检查payables表是否存在）
        $payables = 0;

        // 检查payables表是否存在
        $tableCheckSql = "SHOW TABLES LIKE 'payables'";
        $tableCheckResult = $conn->query($tableCheckSql);

        if ($tableCheckResult && $tableCheckResult->num_rows > 0) {
            $payablesSql = "SELECT SUM(remaining_amount) AS total_payables
                        FROM payables
                        WHERE due_date BETWEEN ? AND ?";

            $payablesStmt = $conn->prepare($payablesSql);
            if (!$payablesStmt) {
                return [false, ["准备应付账款SQL语句失败: " . $conn->error]];
            }

            $payablesStmt->bind_param('ss', $startDate, $endDate);
            $payablesStmt->execute();
            $payablesResult = $payablesStmt->get_result();
            $payablesData = $payablesResult->fetch_assoc();
            $payablesStmt->close();

            $payables = $payablesData['total_payables'] ?? 0;
        } else {
            // 估算应付账款为成本的25%
            $payables = $totalCost * 0.25;
            $messages[] = "未找到payables表，应付账款按成本的25%估算";
        }

        // 7. 获取库存价值
        $inventorySql = "SELECT SUM(i.quantity * p.unit_price) AS total_inventory_value
                        FROM inventory i
                        JOIN products p ON i.product_id = p.product_id";

        $inventoryResult = $conn->query($inventorySql);
        if (!$inventoryResult) {
            return [false, ["获取库存价值数据失败: " . $conn->error]];
        }
        $inventoryData = $inventoryResult->fetch_assoc();
        $inventoryValue = $inventoryData['total_inventory_value'] ?? 0;

        // 8. 计算现金流（简化版：销售额-成本-运营费用+应收账款变化-应付账款变化）
        $cashFlow = $totalSales - $totalCost - $operatingExpenses;

        // 9. 保存财务报表数据
        $insertSql = "INSERT INTO financial_reports (
                    report_date, period_type, total_sales, total_cost, gross_profit, 
                    gross_profit_rate, operating_expenses, net_profit, net_profit_rate,
                    receivables, payables, inventory_value, cash_flow, created_at
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())
                    ON DUPLICATE KEY UPDATE
                    total_sales = VALUES(total_sales),
                    total_cost = VALUES(total_cost),
                    gross_profit = VALUES(gross_profit),
                    gross_profit_rate = VALUES(gross_profit_rate),
                    operating_expenses = VALUES(operating_expenses),
                    net_profit = VALUES(net_profit),
                    net_profit_rate = VALUES(net_profit_rate),
                    receivables = VALUES(receivables),
                    payables = VALUES(payables),
                    inventory_value = VALUES(inventory_value),
                    cash_flow = VALUES(cash_flow),
                    updated_at = NOW()";

        $insertStmt = $conn->prepare($insertSql);
        if (!$insertStmt) {
            return [false, ["准备插入财务报表SQL语句失败: " . $conn->error]];
        }

        $insertStmt->bind_param(
            'ssddddddddddd',
            $date,
            $periodType,
            $totalSales,
            $totalCost,
            $grossProfit,
            $grossProfitRate,
            $operatingExpenses,
            $netProfit,
            $netProfitRate,
            $receivables,
            $payables,
            $inventoryValue,
            $cashFlow
        );

        if (!$insertStmt->execute()) {
            return [false, ["执行插入财务报表SQL语句失败: " . $insertStmt->error]];
        }

        $insertStmt->close();
        $messages[] = "已生成{$periodType}财务报表数据，日期：{$date}";

        return [true, $messages];
    } catch (Exception $e) {
        return [false, ["生成{$periodType}财务报表数据失败: " . $e->getMessage()]];
    }
}

// 脚本开始执行
$startTime = date('Y-m-d H:i:s');
$messages[] = '数据统计脚本开始执行: ' . $startTime;

// 生成热门商品统计数据
generatePopularProductStats();

// 生成库存分析统计数据
generateInventoryAnalysisStats();

// 生成销售分析统计数据
generateSalesAnalysisStats();

// 生成利润分析统计数据
generateProfitAnalysisStats();

// 生成财务报表数据
generateFinancialReportStats();

// 脚本执行完成
$endTime = date('Y-m-d H:i:s');
$messages[] = '数据统计脚本执行完成: ' . $endTime;

// 返回执行结果，如果是直接运行脚本则输出日志信息
if (basename($_SERVER['PHP_SELF']) == basename(__FILE__)) {
    foreach ($messages as $msg) {
        echo $msg . PHP_EOL;
    }
    exit(0);
}
