<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = isset($_GET['message']) ? $_GET['message'] : '';
$messageType = isset($_GET['type']) ? $_GET['type'] : '';

// 获取查询参数
$warehouse_id = isset($_GET['warehouse_id']) ? (int)$_GET['warehouse_id'] : 0;
$product_name = isset($_GET['product_name']) ? trim($_GET['product_name']) : '';
$warning_type = isset($_GET['warning_type']) ? trim($_GET['warning_type']) : 'all';

// 构建查询条件
$whereClause = "WHERE i.quantity <= i.min_stock_level";
$params = [];
$types = "";

// 根据预警类型筛选
if ($warning_type == 'low') {
    $whereClause .= " AND i.quantity <= i.min_stock_level AND i.quantity > 0";
} elseif ($warning_type == 'out') {
    $whereClause .= " AND i.quantity = 0";
}

if ($warehouse_id > 0) {
    $whereClause .= " AND i.warehouse_id = ?";
    $params[] = $warehouse_id;
    $types .= "i";
}

if (!empty($product_name)) {
    $product_name = "%" . $product_name . "%";
    $whereClause .= " AND p.product_name LIKE ?";
    $params[] = $product_name;
    $types .= "s";
}

// 获取所有预警库存记录
$warnings = [];
$sql = "SELECT i.inventory_id, i.product_id, i.warehouse_id, i.quantity as current_stock, i.min_stock_level as min_stock, 
        i.updated_at, p.product_name, p.barcode, p.unit, p.unit_price, 
        w.warehouse_name, w.type as warehouse_type
        FROM inventory i
        JOIN products p ON i.product_id = p.product_id
        JOIN warehouses w ON i.warehouse_id = w.warehouse_id
        $whereClause
        ORDER BY (CASE WHEN i.quantity = 0 THEN 0 ELSE i.quantity / i.min_stock_level END), i.quantity";

$stmt = $conn->prepare($sql);

if ($stmt) {
    if (!empty($params)) {
        $stmt->bind_param($types, ...$params);
    }

    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        // 计算库存状态
        if ($row['current_stock'] == 0) {
            $row['warning_level'] = 'out';
            $row['warning_text'] = '缺货';
        } elseif ($row['current_stock'] <= $row['min_stock']) {
            // 计算百分比
            $percent = $row['min_stock'] > 0 ? ($row['current_stock'] / $row['min_stock']) * 100 : 100;

            if ($percent <= 25) {
                $row['warning_level'] = 'critical';
                $row['warning_text'] = '库存极低';
            } else if ($percent <= 50) {
                $row['warning_level'] = 'warning';
                $row['warning_text'] = '库存不足';
            } else {
                $row['warning_level'] = 'low';
                $row['warning_text'] = '库存偏低';
            }
        } else {
            $row['warning_level'] = 'normal';
            $row['warning_text'] = '库存正常';
        }

        $warnings[] = $row;
    }
    $stmt->close();
} else {
    // 处理prepare失败的情况
    echo '<div class="alert alert-error">数据库查询准备失败: ' . $conn->error . '</div>';
}

// 获取所有仓库
$warehouses = [];
$warehouseSql = "SELECT warehouse_id, warehouse_name, type as warehouse_type FROM warehouses ORDER BY warehouse_name";
$warehouseStmt = $conn->prepare($warehouseSql);
if ($warehouseStmt) {
    $warehouseStmt->execute();
    $warehouseResult = $warehouseStmt->get_result();
    while ($row = $warehouseResult->fetch_assoc()) {
        $warehouses[] = $row;
    }
    $warehouseStmt->close();
} else {
    echo '<div class="alert alert-error">获取仓库列表失败: ' . $conn->error . '</div>';
}

// 统计各类预警数量
$totalWarnings = count($warnings);
$criticalCount = 0;
$warningCount = 0;
$lowCount = 0;
$outCount = 0;

foreach ($warnings as $warning) {
    if ($warning['warning_level'] == 'critical') {
        $criticalCount++;
    } elseif ($warning['warning_level'] == 'warning') {
        $warningCount++;
    } elseif ($warning['warning_level'] == 'low') {
        $lowCount++;
    } elseif ($warning['warning_level'] == 'out') {
        $outCount++;
    }
}
?>

<!-- 引入 jQuery 和 Select2 库 -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.min.js"></script>
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 搜索表单 -->
<div class="module-tools">
    <div class="tool-left">
        <h4>库存预警</h4>
    </div>
    <div class="tool-right">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="warning">

            <div class="search-group">
                <select name="warehouse_id" class="search-input select2-warehouse">
                    <option value="">所有仓库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo $warehouse_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="search-group">
                <input type="text" name="product_name" class="search-input" placeholder="商品名称" value="<?php echo htmlspecialchars($product_name); ?>">
            </div>

            <div class="search-group">
                <select name="warning_type" class="search-input select2-warning-type">
                    <option value="all" <?php echo $warning_type == 'all' ? 'selected' : ''; ?>>所有预警</option>
                    <option value="low" <?php echo $warning_type == 'low' ? 'selected' : ''; ?>>库存不足</option>
                    <option value="out" <?php echo $warning_type == 'out' ? 'selected' : ''; ?>>缺货</option>
                </select>
            </div>

            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=warning" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 预警统计 -->
<div class="warning-stats">
    <div class="stat-item">
        <span class="stat-label">总预警数:</span>
        <span class="stat-value"><?php echo $totalWarnings; ?></span>
    </div>
    <div class="stat-item">
        <span class="stat-label">库存极低:</span>
        <span class="stat-value text-critical"><?php echo $criticalCount; ?></span>
    </div>
    <div class="stat-item">
        <span class="stat-label">库存不足:</span>
        <span class="stat-value text-warning"><?php echo $warningCount; ?></span>
    </div>
    <div class="stat-item">
        <span class="stat-label">库存偏低:</span>
        <span class="stat-value text-low"><?php echo $lowCount; ?></span>
    </div>
    <div class="stat-item">
        <span class="stat-label">缺货:</span>
        <span class="stat-value text-out"><?php echo $outCount; ?></span>
    </div>
</div>

<!-- 批量设置 -->
<div class="batch-actions">
    <form id="batch-form" method="post" action="" class="batch-form">
        <input type="hidden" name="action" value="batch_update">
        <div class="search-group">
            <input type="number" name="batch_min_stock" class="search-input" placeholder="批量设置最低库存" min="0">
        </div>
        <div class="search-group">
            <label>
                <input type="checkbox" name="batch_warning_enabled"> 启用预警
            </label>
        </div>
        <button type="submit" class="btn btn-primary" id="batch-update-btn" disabled>批量更新</button>
    </form>
</div>

<!-- 预警列表 -->
<div class="data-wrapper">
    <table class="data-table">
        <thead>
            <tr>
                <th><input type="checkbox" id="select-all"></th>
                <th>ID</th>
                <th>仓库</th>
                <th>商品名称</th>
                <th>条码</th>
                <th>当前库存</th>
                <th>最低库存</th>
                <th>状态</th>
                <th>更新时间</th>
                <th>预警设置</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($warnings) > 0): ?>
                <?php foreach ($warnings as $warning): ?>
                    <tr class="warning-level-<?php echo $warning['warning_level']; ?>">
                        <td>
                            <input type="checkbox" class="select-item" name="inventory_ids[]" form="batch-form" value="<?php echo $warning['inventory_id']; ?>">
                        </td>
                        <td><?php echo $warning['inventory_id']; ?></td>
                        <td><?php echo htmlspecialchars($warning['warehouse_name']); ?></td>
                        <td><?php echo htmlspecialchars($warning['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($warning['barcode']); ?></td>
                        <td><?php echo $warning['current_stock']; ?></td>
                        <td><?php echo $warning['min_stock']; ?></td>
                        <td>
                            <span class="badge badge-<?php echo $warning['warning_level']; ?>">
                                <?php echo $warning['warning_text']; ?>
                            </span>
                        </td>
                        <td><?php echo $warning['updated_at']; ?></td>
                        <td>
                            <form method="post" action="" class="form-inline">
                                <input type="hidden" name="action" value="update_warning">
                                <input type="hidden" name="inventory_id" value="<?php echo $warning['inventory_id']; ?>">
                                <div class="form-inline-group">
                                    <input type="number" name="min_stock" value="<?php echo $warning['min_stock']; ?>" min="0" class="form-inline-input" placeholder="最低库存">
                                </div>
                                <div class="form-inline-group">
                                    <label>
                                        <input type="checkbox" name="warning_enabled" <?php echo $warning['warning_enabled'] ? 'checked' : ''; ?>> 启用
                                    </label>
                                </div>
                                <button type="submit" class="btn btn-primary btn-sm">保存</button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="10" class="text-center">暂无预警数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<style>
    .warning-stats {
        display: flex;
        justify-content: flex-start;
        margin-bottom: 20px;
        background-color: #f9f9f9;
        padding: 15px;
        border-radius: 5px;
    }

    .stat-item {
        margin-right: 30px;
    }

    .stat-label {
        font-weight: bold;
        margin-right: 5px;
    }

    .stat-value {
        color: #2c3e50;
    }

    .text-critical {
        color: #dc3545;
        font-weight: bold;
    }

    .text-warning {
        color: #ffc107;
        font-weight: bold;
    }

    .text-low {
        color: #fd7e14;
        font-weight: bold;
    }

    .text-out {
        color: #dc3545;
        font-weight: bold;
    }

    .warning-level-critical td {
        background-color: #f8d7da;
    }

    .warning-level-warning td {
        background-color: #fff3cd;
    }

    .warning-level-low td {
        background-color: #fff8e1;
    }

    .warning-level-out td {
        background-color: #f8d7da;
    }

    .badge-critical {
        background-color: #dc3545;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #343a40;
    }

    .badge-low {
        background-color: #fd7e14;
        color: white;
    }

    .badge-out {
        background-color: #dc3545;
        color: white;
    }

    .badge-normal {
        background-color: #28a745;
        color: white;
    }

    .form-inline {
        display: flex;
        align-items: center;
    }

    .form-inline-group {
        margin-right: 10px;
    }

    .form-inline-input {
        width: 60px;
        padding: 4px;
        border: 1px solid #ccc;
        border-radius: 3px;
    }

    .batch-actions {
        display: flex;
        justify-content: flex-start;
        margin-bottom: 20px;
        padding: 15px;
        background-color: #e9ecef;
        border-radius: 5px;
    }

    .batch-form {
        display: flex;
        align-items: center;
    }
</style>

<script>
    $(document).ready(function() {
        // 初始化 Select2
        $('.select2-warehouse').select2({
            placeholder: "请选择仓库",
            allowClear: true,
            width: '100%'
        });

        $('.select2-warning-type').select2({
            placeholder: "请选择预警类型",
            allowClear: true,
            width: '100%'
        });

        // 全选/取消全选
        const selectAll = document.getElementById('select-all');
        const selectItems = document.querySelectorAll('.select-item');
        const batchUpdateBtn = document.getElementById('batch-update-btn');

        // 全选/取消全选
        selectAll.addEventListener('change', function() {
            selectItems.forEach(item => {
                item.checked = selectAll.checked;
            });
            updateBatchButtonState();
        });

        // 单项选择时更新全选状态
        selectItems.forEach(item => {
            item.addEventListener('change', function() {
                let allChecked = true;
                selectItems.forEach(item => {
                    if (!item.checked) {
                        allChecked = false;
                    }
                });
                selectAll.checked = allChecked;
                updateBatchButtonState();
            });
        });

        // 更新批量按钮状态
        function updateBatchButtonState() {
            let anyChecked = false;
            selectItems.forEach(item => {
                if (item.checked) {
                    anyChecked = true;
                }
            });
            batchUpdateBtn.disabled = !anyChecked;
        }
    });
</script>