<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取会员等级信息
$levelSql = "SELECT * FROM member_levels ORDER BY min_points ASC";
$levelResult = $conn->query($levelSql);
$memberLevels = [];
while ($levelResult && $row = $levelResult->fetch_assoc()) {
    $memberLevels[$row['level_id']] = $row;
}

// 获取未成为会员的客户列表
$customerSql = "SELECT c.* 
                FROM customers c 
                LEFT JOIN members m ON c.customer_id = m.customer_id 
                WHERE m.member_id IS NULL 
                ORDER BY c.customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $customer_id = isset($_POST['customer_id']) ? intval($_POST['customer_id']) : 0;
    $member_no = isset($_POST['member_no']) ? sanitize($_POST['member_no']) : '';
    $level_id = isset($_POST['level_id']) ? intval($_POST['level_id']) : 0;
    $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
    $join_date = isset($_POST['join_date']) ? sanitize($_POST['join_date']) : date('Y-m-d');
    $status = isset($_POST['status']) ? sanitize($_POST['status']) : 'active';
    $remark = isset($_POST['remark']) ? sanitize($_POST['remark']) : '';

    // 验证数据
    $errors = [];
    if (empty($customer_id)) {
        $errors[] = '请选择客户';
    }

    if (empty($member_no)) {
        $errors[] = '会员卡号不能为空';
    } else {
        // 检查会员卡号是否已存在
        $checkSql = "SELECT COUNT(*) as count FROM members WHERE member_no = ?";
        $stmt = $conn->prepare($checkSql);
        if ($stmt) {
            $stmt->bind_param("s", $member_no);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($result && $result->fetch_assoc()['count'] > 0) {
                $errors[] = '会员卡号已存在，请使用其他卡号';
            }
            $stmt->close();
        }
    }

    if (empty($level_id)) {
        $errors[] = '请选择会员等级';
    }

    if (empty($join_date)) {
        $errors[] = '入会日期不能为空';
    } elseif (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $join_date)) {
        $errors[] = '入会日期格式无效，请使用YYYY-MM-DD格式';
    }

    // 如果没有错误，则保存数据
    if (empty($errors)) {
        // 准备SQL语句
        $sql = "INSERT INTO members (customer_id, member_no, level_id, points, join_date, status, remark) 
                VALUES (?, ?, ?, ?, ?, ?, ?)";

        $stmt = $conn->prepare($sql);
        if ($stmt) {
            // 绑定参数
            $stmt->bind_param("isiisss", $customer_id, $member_no, $level_id, $points, $join_date, $status, $remark);

            // 执行
            if ($stmt->execute()) {
                $new_member_id = $stmt->insert_id;

                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 添加了新会员，客户ID：{$customer_id}，会员卡号：{$member_no}";
                log_operation($_SESSION['user_id'], '添加', $operationDetails);

                // 设置成功消息并重定向回列表页
                $_SESSION['message'] = '新会员添加成功，会员卡号: ' . $member_no;
                $_SESSION['message_type'] = 'success';

                // 跳转到会员列表页面
                header("Location: index.php?page=member");
                exit;
            } else {
                $message = '添加会员失败: ' . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    } else {
        // 显示验证错误
        $message = implode('<br>', $errors);
        $messageType = 'error';
    }
}

// 生成会员卡号（年月日+4位随机数）
$default_member_no = date('Ymd') . sprintf("%04d", rand(0, 9999));
?>

<div class="page-header">
    <h3>添加新会员</h3>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="form-wrapper">
    <form action="index.php?page=member&action=add" method="post" class="data-form">
        <div class="form-group">
            <label for="customer_id">选择客户 <span class="required">*</span></label>
            <select id="customer_id" name="customer_id" class="form-control" required>
                <option value="">-- 请选择客户 --</option>
                <?php foreach ($customers as $customer): ?>
                    <option value="<?php echo $customer['customer_id']; ?>" <?php echo isset($_POST['customer_id']) && $_POST['customer_id'] == $customer['customer_id'] ? 'selected' : ''; ?>>
                        <?php echo htmlspecialchars($customer['customer_name']); ?>
                        (<?php echo htmlspecialchars($customer['phone'] ?: '无电话'); ?>)
                    </option>
                <?php endforeach; ?>
            </select>
            <?php if (count($customers) == 0): ?>
                <small class="text-danger">没有可以添加为会员的客户。请先在销售管理模块添加客户。</small>
            <?php endif; ?>
        </div>

        <div class="form-group">
            <label for="member_no">会员卡号 <span class="required">*</span></label>
            <input type="text" id="member_no" name="member_no" class="form-control" value="<?php echo isset($_POST['member_no']) ? htmlspecialchars($_POST['member_no']) : $default_member_no; ?>" required>
            <small>会员卡号必须唯一，建议使用系统自动生成的编号</small>
        </div>

        <div class="form-group">
            <label for="level_id">会员等级 <span class="required">*</span></label>
            <select id="level_id" name="level_id" class="form-control" required>
                <option value="">-- 请选择会员等级 --</option>
                <?php foreach ($memberLevels as $level): ?>
                    <option value="<?php echo $level['level_id']; ?>" <?php echo isset($_POST['level_id']) && $_POST['level_id'] == $level['level_id'] ? 'selected' : ''; ?>>
                        <?php echo htmlspecialchars($level['level_name']); ?>
                        (折扣率: <?php echo $level['discount_rate']; ?>, 最低积分: <?php echo $level['min_points']; ?>)
                    </option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="form-row">
            <div class="form-group half">
                <label for="points">初始积分</label>
                <input type="number" id="points" name="points" class="form-control" value="<?php echo isset($_POST['points']) ? intval($_POST['points']) : 0; ?>" min="0">
            </div>

            <div class="form-group half">
                <label for="join_date">入会日期 <span class="required">*</span></label>
                <input type="date" id="join_date" name="join_date" class="form-control" value="<?php echo isset($_POST['join_date']) ? htmlspecialchars($_POST['join_date']) : date('Y-m-d'); ?>" required>
            </div>
        </div>

        <div class="form-group">
            <label for="status">会员状态</label>
            <select id="status" name="status" class="form-control">
                <option value="active" <?php echo (!isset($_POST['status']) || $_POST['status'] == 'active') ? 'selected' : ''; ?>>激活</option>
                <option value="inactive" <?php echo (isset($_POST['status']) && $_POST['status'] == 'inactive') ? 'selected' : ''; ?>>停用</option>
            </select>
        </div>

        <div class="form-group">
            <label for="remark">备注</label>
            <textarea id="remark" name="remark" class="form-control" rows="3"><?php echo isset($_POST['remark']) ? htmlspecialchars($_POST['remark']) : ''; ?></textarea>
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">保存</button>
            <a href="index.php?page=member" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<style>
    .form-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .page-header {
        margin-bottom: 20px;
    }

    .data-form {
        max-width: 800px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .form-group.half {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
        box-sizing: border-box;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #e9ecef;
    }

    .required {
        color: #dc3545;
    }

    label {
        font-weight: bold;
        margin-bottom: 5px;
        display: block;
    }

    small {
        display: block;
        margin-top: 5px;
        color: #6c757d;
    }

    .text-danger {
        color: #dc3545;
    }

    @media (max-width: 767.98px) {
        .form-group.half {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>